aboutsummaryrefslogtreecommitdiff
path: root/toolchain_utils_githooks/check-presubmit.py
diff options
context:
space:
mode:
authorGeorge Burgess IV <gbiv@google.com>2022-04-21 10:27:37 -0700
committerChromeos LUCI <chromeos-scoped@luci-project-accounts.iam.gserviceaccount.com>2022-04-21 23:29:15 +0000
commit2124be5caee6803d5bfe6f7cdc8e3367cb375807 (patch)
tree8a89bb5f1b464c079d10fbe69b5ee7580b3cbe44 /toolchain_utils_githooks/check-presubmit.py
parent424b0f6a965d95139c6e19ec1d37a1d6ce0dc47d (diff)
downloadtoolchain-utils-2124be5caee6803d5bfe6f7cdc8e3367cb375807.tar.gz
toolchain_utils: s/Cr OS/CrOS/g
Result of running `sed -ri 's/Chrom(ium|e) OS/Chrom\1OS/g' $(find -type f)`. BUG=None TEST=None Change-Id: I59be92537aa19bc989f52b585e307e76dbde401b Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/toolchain-utils/+/3600147 Reviewed-by: Manoj Gupta <manojgupta@chromium.org> Commit-Queue: George Burgess <gbiv@chromium.org> Tested-by: George Burgess <gbiv@chromium.org>
Diffstat (limited to 'toolchain_utils_githooks/check-presubmit.py')
-rwxr-xr-xtoolchain_utils_githooks/check-presubmit.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/toolchain_utils_githooks/check-presubmit.py b/toolchain_utils_githooks/check-presubmit.py
index 99500acd..fe9648a6 100755
--- a/toolchain_utils_githooks/check-presubmit.py
+++ b/toolchain_utils_githooks/check-presubmit.py
@@ -1,7 +1,7 @@
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
-# Copyright 2019 The Chromium OS Authors. All rights reserved.
+# Copyright 2019 The ChromiumOS Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
@@ -248,7 +248,7 @@ def check_cros_lint(
toolchain_utils_root,
env=fixed_env)
# This is returned specifically if cros couldn't find the Chrome OS tree
# root.
if exit_code == 127:
return None
@@ -310,9 +310,9 @@ def check_cros_lint(
tasks.append(('golint', thread_pool.apply_async(run_golint)))
complaint = '\n'.join((
- 'WARNING: No Chrome OS checkout detected, and no viable CrOS tree',
+ 'WARNING: No ChromeOS checkout detected, and no viable CrOS tree',
'found; falling back to linting only python and go. If you have a',
- 'Chrome OS checkout, please either develop from inside of the source',
+ 'ChromeOS checkout, please either develop from inside of the source',
'tree, or set $CHROMEOS_ROOT_DIRECTORY to the root of it.',
))
@@ -248,7 +248,7 @@ def check_cros_lint(
toolchain_utils_root,
env=fixed_env)
- # This is returned specifically if cros couldn't find the Chrome OS tree
+ # This is returned specifically if cros couldn't find the ChromeOS tree
# root.
if exit_code == 127: